@@ -14,12 +14,12 @@ C::TinyCompiler - Full C JIT compiling using the Tiny C Compiler
 
 =head1 VERSION
 
-Version 0.03
+Version 0.02
 
 =cut
 
 BEGIN {
-	our $VERSION = '0.03_01';
+	our $VERSION = '0.02';
 	use XSLoader;
 	XSLoader::load 'C::TinyCompiler', $VERSION;
 }
@@ -227,16 +227,6 @@ sub new {
 		pp_defs => {},
 	};
 	
-	# Add Mac typedefs:
-	$self->{Head} = line_number(__LINE__) . q{
-		/* http://comments.gmane.org/gmane.comp.compilers.tinycc.devel/325 */
-		typedef unsigned short __uint16_t, uint16_t;
-		typedef unsigned int __uint32_t, uint32_t;
-		typedef unsigned long __uint64_t, uint64_t;
-		
-		#line 1 "whatever comes after Mac typedefs"
-	} if $^O =~ /darwin/;
-	
 	# Process any packages:
 	$self->apply_packages(@_);
 	
@@ -245,21 +235,11 @@ sub new {
 }
 
 # Report errors if they crop-up:
-sub report_if_trouble {
+sub report_if_error {
 	my ($self, $to_say) = @_;
-	my $msg = $self->get_error_message;
-	
-	# Don't do anything if we have nothing to worry about.
-	return unless $msg;
-	
-	# Handle warnings more gently than errors:
-	if ($msg =~ /warning/) {
+	if (my $msg = $self->get_error_message) {
 		$to_say =~ s/MESSAGE/$msg/;
-		warnings::warnif('Warning ' . $to_say);
-	}
-	else {
-		$to_say =~ s/MESSAGE/$msg/;
-		croak('Error ' . $to_say);
+		croak($to_say);
 	}
 }
 
@@ -665,8 +645,6 @@ sub undefine {
 
 =head2 code
 
-XXX THIS INTERFACE IS LIKELY TO CHANGE IN THE NEAR FUTURE XXX
-
 This lvalue sub lets you get, set, append to, and otherwise modify the contents
 of the code in each of three regions. Any value is allowed so long as the
 compile-phase can retrieve a useful string. This means that you can even set
@@ -1096,17 +1074,17 @@ sub compile {
 	my %defs = %{$self->{pp_defs}};
 	while (my ($name, $value) = each %defs) {
 		$self->_define($name, $value);
-		$self->report_if_trouble("defining preprocessor symbol [$name]: MESSAGE");
+		$self->report_if_error("Error defining preprocessor symbol [$name]: MESSAGE");
 	}
 	$self->_add_include_paths(@{$self->{include_paths}});
 	$self->_add_sysinclude_paths(@{$self->{sysinclude_paths}});
-	$self->report_if_trouble("adding include path(s): MESSAGE");
+	$self->report_if_error("Error adding include path(s): MESSAGE");
 	
 	# Add the library stuff:
 	$self->_add_library_paths(@{$self->{library_paths}});
-	$self->report_if_trouble("adding library path(s): MESSAGE");
+	$self->report_if_error("Error adding library path(s): MESSAGE");
 	$self->_add_libraries(@{$self->{libraries}});
-	$self->report_if_trouble("adding library(s): MESSAGE");
+	$self->report_if_error("Error adding library(s): MESSAGE");
 	
 	# Allow packages to perform any preprocessing they may want:
 	while (my ($package, $options) = each %{$self->{applied_package}}) {
@@ -1122,10 +1100,8 @@ sub compile {
 		$self->_compile($code);
 		1;
 	} or do {
-		# We ran into a problem! This exception will only get tripped if
-		# libtcc's compile function returned nonzero, which means there was
-		# an error. Warnings do not cause _compile to throw exceptions. So,
-		# report the compiler issue as reported from the compiled line:
+		# We ran into a problem! Report the compiler issue (as reported from
+		# the compiled line) if known:
 		my $message = $self->get_error_message;
 		if ($message) {
 			# Fix the rather terse line number notation:
@@ -1140,10 +1116,8 @@ sub compile {
 		
 		# Otherwise report an unknown compiler issue, indicating the line in the
 		# Perl script that called for the compile action:
-		croak("C::TinyCompiler weird internal error: Unable to compile for unknown reasons");
+		croak("Unable to compile for unknown reasons");
 	};
-	# Report any warnings
-	$self->report_if_trouble('compiling: MESSAGE');
 	
 	# Apply the pre-compiled symbols (function pointers, etc):
 	while (my ($package, $options) = each %{$self->{applied_package}}) {
@@ -1151,7 +1125,7 @@ sub compile {
 	}
 	# Apply any other symbols that were added:
 	$self->_add_symbols(%{$self->{symbols}});
-	$self->report_if_trouble("adding symbol(s): MESSAGE");
+	$self->report_if_error("Error adding symbol(s): MESSAGE");
 
 	# Relocate
 	eval {
@@ -1159,9 +1133,9 @@ sub compile {
 		1;
 	} or do {
 		# We ran into a problem! Report the relocation issue, if known:
-		$self->report_if_trouble("relocating: MESSAGE");
+		$self->report_if_error("Unable to relocate: MESSAGE");
 		# Report an unknown relocation issue if not known:
-		croak("C::TinyCompiler weird internal error: Unable to relocate for unknown reasons");
+		croak("Unable to relocate for unknown reasons");
 	};
 	
 	# Mark the compiler as post-compile
